Biblelator
==========
This file last updated: 2016-03-30 RJH


A (hackable) multi-window Bible editor written in Python3.

See http://Freely-Given.org/Software/Biblelator

This has been used daily by the developer as a production Bible editor since February 2016
as an alternative to Paratext for editing Paratext USFM Bible files (on Ubuntu Linux).
The first alpha release (v0.30) was advertised in mid-March 2016.
It is still being continuously developed with many more features to come
and many early features to be further extended and polished.

By including the Bible Organisational System (BibleOrgSys), Biblelator is able
to display most un-encrypted Bibles that you have on your computer as translation
resources, and is also able to export Bibles into a large number of formats.

Some documentation can be found in the Documentation folder
    including DevelopmentPrinciples.md, Installation.md, GettingStarted.md, KeyboardShortcuts.md,
    and ForProgrammers.md.
